NLSL: dfunc Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
dfunc Module Reference

## Variables
double precision, save | dlam
double precision, save | xi
double precision, save | cc
double precision, save | ss

## Variable Documentation

double precision, save dfunc::cc

Definition at line 19 of file dfunc.f90.

double precision, save dfunc::dlam

Definition at line 19 of file dfunc.f90.

double precision, save dfunc::ss

Definition at line 19 of file dfunc.f90.

double precision, save dfunc::xi

Definition at line 19 of file dfunc.f90.